SetPackageInfo( rec(
  PackageName := "RAQ",
  Subtitle := "Racks And Quandles in GAP",
  Version := "0.1.0",
  Date := "2018-Oct-1",
  PackageWWWPrefix := Concatenation("http://code.studioinfinity.org/",
                                    ~.PackageName),
  PackageWWWHome := Concatenation(~.PackageWWWPrefix, "/wiki"),
  SourceRepository := rec( Type := "git", URL := ~.PackageWWWPrefix ),
  IssueTrackerURL := Concatenation(~.PackageWWWPrefix, "/issues"),
  SupportEmail := "glen@studioinfinity.org",
  ArchiveURL := Concatenation(~.PackageWWWPrefix, "/releases"),
  ArchiveFormats := ".tar.gz",

  Persons := [
    rec(
      LastName      := "Whitney",
      FirstNames    := "Glen",
      IsAuthor      := true,
      IsMaintainer  := true,
      Email         := "glen@studioinfinity.org",
      WWWHome       := "http://studioinfinity.org",
      PostalAddress := Concatenation( [
                         "523 Rialto Ave.\n",
                         "Venice, CA 90291\n",
                         "USA" ] ),
      Place         := "Venice",
      Institution   := "studioInfinity.org"
   )
  ],

##  Status information. Currently the following cases are recognized:
##    "accepted"      for successfully refereed packages
##    "deposited"     for packages for which the GAP developers agreed 
##                    to distribute them with the core GAP system
##    "dev"           for development versions of packages 
##    "other"         for all other packages
##
  Status := "other",

  README_URL := Concatenation(~.PackageWWWPrefix,
                              "/src/branch/master/README.md"),
  PackageInfoURL := Concatenation(~.PackageWWWPrefix,
                                  "/src/branch/master/PackageInfo.g"),

  AbstractHTML := Concatenation( 
    "The <span class=\"pkgname\">RAQ</span> package provides researchers ",
    "with means of representing and computing with general one-sided ",
    "quasigroups, but more more particularly with racks and quandles. ",
    "This package builds on fundamentals of non-associated algebra ",
    "established in the <span class=\"pkgname\">LOOPS</span> package, and ",
    "and provides enhanced functionality, libraries, and implementations ",
    "as compared to the earlier <span class=\"pkgname\">RIG</span> package ",
    "on which <span class=\"pkgname\">RAQ</span> is generally modeled."
  ),
               
  PackageDoc := rec(
    BookName  := "raq",
    ArchiveURLSubset := ["doc"],
    HTMLStart := "doc/chap0.html",
    PDFFile   := "doc/manual.pdf",
    SixFile   := "doc/manual.six",
    LongTitle := "The raq Package: Racks And Quandles in GAP",
    Autoload  := true     # only for the documentation, TEMPORARILY TURNED OFF
  ),


  Dependencies := rec(
    GAP := ">=4.4",
    NeededOtherPackages := [["loops","3.3.0"], ["circle","1.0.0"]],
    SuggestedOtherPackages := [],
    ExternalConditions := []
  ),

  AvailabilityTest := ReturnTrue,
  BannerString := Concatenation("--\nRAQ, Racks And Quandles in GAP, Version ",
                                ~.Version, ".\n--\n"),

  Autoload := false,  # false for deposited packages
  TestFile := "tst/testall.g",
  Keywords := ["quasigroup", "self-distributive", "rack", "quandle",
             "nichols algebra", "knots"]
));
